###########################################################################
#
#   Copyright (c) 2001 Morten W. Petersen <morten@esol.no>
#	Copyright (c) 2001 Thingamy Ltd.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
#    MA 02111-1307 USA
#
#
###########################################################################

# $Author: morten $
# $Revision: 1.0 $

from ZPublisher.HTTPRequest import html_quote
html_quote_function = html_quote

class html_widget_base:
	"""Base class for HTML widgets."""

	name = ''


	def render(self, html_quote=1):
		"""Returns an HTML presentation of the object."""

		return self.__str__(html_quote=html_quote)


class text(html_widget_base):
	"""Class for handling <input type="text"> tags."""

	def __init__(self, name='', value='', size=50):
		"""Initalizies the text widget."""

		self.name = name
		self.value = value
		self.size = size

	def __str__(self, html_quote=1):
		"""Returns an HTML presentation of the widget."""

		if html_quote:

			value = html_quote_function(self.value)

		else:

			value = self.value

		return """<input type="text" name="%s" size="%s" value="%s" />""" % \
				(self.name, self.size, self.value)


class textarea(html_widget_base):
	"""Class for handling <textarea> tags."""

	def __init__(self, name='', value='', rows=10, cols=60):
		"""Initializes the textarea widget."""

		self.name = name
		self.value = value
		self.rows = rows
		self.cols = cols


	def __str__(self, html_quote=1):
		"""Returns an HTML presentation of the widget."""

		if html_quote:

			value = html_quote_function(self.value)

		else:

			value = self.value

		return """<textarea name="%s" rows="%s" cols="%s">%s</textarea>""" % \
				(self.name, self.rows, self.cols, value)


class select_option(html_widget_base):
	"""Class used for handling <option> tags within <select> tags."""

	def __init__(self, value, displayed_value=None,
			selected=None):
		"""Initializes the option."""

		self.value = value

		if displayed_value is None:

			self.displayed_value = value

		else:

			self.displayed_value = displayed_value

		self.selected = selected


	def select(self):
		"""Sets the selected flag to true."""

		self.selected = 1


	def unselect(self):
		"""Sets the selected flag to false."""

		self.selected = 0


	def __str__(self, html_quote=1):
		"""Returns an HTML presentation."""

		if self.selected:

			selected = " selected"

		else:

			selected = ""

		if html_quote:

			value = html_quote_function(self.value)
			displayed_value = html_quote_function(self.displayed_value)

		else:

			value = self.value
			displayed_value = displayed_value

		return """<option value="%s"%s>%s</option>""" % \
				(value, selected, displayed_value)


class radio_option:
	"""Class for handling a single <input type="radio"> within a group of them."""

	def __init__(self, name='', value='', displayed_value=None,
			selected=None):
		"""Initializes the option."""

		self.name = name
		self.value = value

		if displayed_value is None:

			self.displayed_value = value

		else:

			self.displayed_value = displayed_value

		self.selected = selected


	def select(self):
		"""Sets the selected flag to true."""

		self.selected = 1


	def unselect(self):
		"""Sets the selected flag to false."""

		self.selected = 0


	def __str__(self, html_quote=1):
		"""Returns an HTML presentation."""

		if self.selected:

			selected = " selected"

		else:

			selected = ""

		if html_quote:

			value = html_quote_function(self.value)
			displayed_value = html_quote_function(self.displayed_value)

		else:

			value = self.value
			displayed_value = displayed_value

		return """<input type="radio" name="%s" value="%s" />%s""" % \
				(self.name, self.value, selected, self.displayed_value)


class radio(html_widget_base):
	"""Class used for handling a selection of <input type="radio"> tags."""

	def __init__(self, name='', true='Yes', false='No'):
		"""Initialize the widget."""

		self.name = name
		self.options = []


	def add_option(self, value, displayed_value=None,
			selected=None):

		self.options.append(radio_option(name=self.name, value=value,
					displayed_value=displayed_value,
					selected=selected))


	def __str__(self, html_quote=1):
		"""Returns an HTML presentation of the widget."""

		html = ""

		for option in self.options:

			if option.selected:

				selected = " checked"

			else:

				selected = ""

			if html_quote:

				value = html_quote_function(self.value)

			else:

				value = self.value

			html = html + """<input type="radio" name="%s" value="%s" %s>""" %\
					(self.name, value, selected)

		return html


class select(html_widget_base):
	"""Class for handling <select> tags."""

	def __init__(self, name='', multiple=None, size=1):
		"""Initializes the widget."""

		self.name = name
		self.multiple = multiple
		self.options = []


	def add_option(self, value, displayed_value=None,
			selected=None):
		"""Adds an option to the selection."""

		self.options.append(select_option(
					value, displayed_value=displayed_value,
					selected=selected))


	def __str__(self, html_quote=1):
		"""Returns an HTML presentation of the widget."""

		if self.multiple:

			multiple = " multiple"

		else:

			multiple = ""

		html = """<select name="%s"%s>""" % (self.name, multiple)

		for option in self.options:

			html = html + option.render(html_quote=html_quote)

		return html + "</select>"
